@@ -1,10 +1,5 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        visionpipeline.h
-// Purpose:  
-// Author:      Cesar Mauri Loba (cesar at crea-si dot com)
-// Modified by: 
-// Created:     
-// Copyright:   (C) 2008-16 Cesar Mauri Loba - CREA Software Systems
+// Copyright:   (C) 2008-19 Cesar Mauri Loba - CREA Software Systems
 // 
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,7 +19,6 @@
 #define VISIONPIPELINE_H
 
 #include "crvimage.h"
-#include "crvhistogram.h"
 #include "configbase.h"
 #include "visiblenormroi.h"
 #include "waittime.h"
@@ -35,12 +29,17 @@
 
 class CVisionPipeline : public CConfigBase, wxThread
 {
-	// Methods
 public:
 	CVisionPipeline (wxThreadKind kind = wxTHREAD_JOINABLE);
 	~CVisionPipeline();
 
-	enum ECpuUsage {CPU_LOWEST= 0, CPU_LOW, CPU_NORMAL, CPU_HIGH, CPU_HIGHEST};
+	enum ECpuUsage { 
+        CPU_LOWEST= 0, 
+        CPU_LOW, 
+        CPU_NORMAL, 
+        CPU_HIGH, 
+        CPU_HIGHEST
+    };
 
 	// Thread entry point
 	virtual wxThread::ExitCode Entry();
@@ -74,7 +73,6 @@ public:
 	virtual void ReadProfileData(wxConfigBase* pConfObj);
 
 private:
-	// Track area
 	CVisibleNormROI m_trackArea;
 
 	bool m_trackFace;
@@ -86,7 +84,6 @@ private:
 		
 	CIplImage m_imgThread;
 	CIplImage m_imgPrev, m_imgCurr;
-	TCrvLookupTable m_prevLut;
 	
 	cv::CascadeClassifier m_faceCascade;
 	int m_threadPeriod;
@@ -99,12 +96,9 @@ private:
 	CvRect m_faceLocation;
 	int m_faceLocationStatus; // 0 -> not available, 1 -> available
 
-	// Corner array
-	enum { NUM_CORNERS = 15 };
-	CvPoint2D32f m_corners[NUM_CORNERS];
-	int m_corner_count;
+	enum { NUM_CORNERS = 20 };
+    std::vector<cv::Point2f> m_corners;
 	
-	// Private methods
 	void AllocWorkingSpace (CIplImage &image);
 	int PreprocessImage ();
 	void ComputeFaceTrackArea (CIplImage &image);
